# OldAS - A Python library for interacting with TheOldReader

## Introduction

OldAS is a library designed to allow async-friendly interaction with [the
API](https://github.com/theoldreader/api) for
[TheOldReader](https://theoldreader.com).

## Installing

`oldas` is [available from pypi](https://pypi.org/project/oldas/) and can be
installed with `pip` or similar Python package tools:

```shell
$ pip install oldas
```

[//]: # (README.md ends here)
